@@ -8,7 +8,7 @@ elif [[ "$DISTRIB" == "ubuntu" ]]; then
     source $VIRTUALENV/bin/activate
 fi
 
-if [[ "TEST_DOCSTRING" == 'true' ]]; then
+if [[ "$TEST_DOCSTRINGS" == 'true' ]]; then
     make test-doc
     pytest -vsl maint_tools/test_docstring.py
 fi
