@@ -12,7 +12,7 @@ run_tests(){
     # Get into a temp directory to run test from the installed scikit learn and
     # check if we do not leave artifacts
     mkdir -p $TEST_DIR
-    # We need the setup.cfg for the nose settings
+    # We need the setup.cfg for the pytest settings
     cp setup.cfg $TEST_DIR
     cd $TEST_DIR
 
@@ -21,11 +21,18 @@ run_tests(){
     python -c "import scipy; print('scipy %s' % scipy.__version__)"
     python -c "import multiprocessing as mp; print('%d CPUs' % mp.cpu_count())"
 
-    py.test --cov=$MODULE -r sx --pyargs $MODULE
+    pytest --cov=$MODULE -r sx --pyargs $MODULE
 
     # Test doc
     cd $OLDPWD
-    make test-doc
+    if [[ "$TEST_DOC" == "true" ]]; then
+        make test-doc
+    fi
+
+    # Validate numpydoc style
+    if [[ "$TEST_NUMPYDOC" == "true" ]]; then
+        pytest -vsl maint_tools/test_docstring.py
+    fi
 }
 
 if [[ "$SKIP_TESTS" != "true" ]]; then
